<?php
  include_once("header.php");
  include_once("formvalidator.php"); 
 function chkuseremail($keyname,$keyvalue)
{
    global $connection;
    $query=mysql_query("select * from user where $keyname='$keyvalue'");
    $row=mysql_num_rows($query);
    if($row!=0) return false;
    else return true;
}
  if(!$start)$start=0;  
       $validator = new FormValidator();
        $validator->addValidation('user_name','req','من فضلك ادخل  الاسم') ;
       $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;
      
       if(isset($submit)&&$validator->ValidateForm()&&chkuseremail('user_name',$_POST['user_name'])&&chkuseremail('email',$_POST['email']))
      {
          
        mysql_query("insert into user values('','1','$user_name',
           '".md5($password)."','$email','$country','$city','$phone','$mobile','1')");
           $sub= "تم التسجيل بنجاح";
           header( 'refresh: 2; url=support.php' ); 
      }
      else
      {
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            }
             if(!chkuseremail('user_name',$_POST['user_name']))
           {
               $msg .="<br>\nاسم المستخدم موجود مسبقا";
           }
           if(!chkuseremail('email',$_POST['email']))
           {
              $msg .="<br>\nالبريد موجود مسبقا"; 
           }
          else
          {
            $display="none";  
          } 
        $sub = Template_Array("$site_template/register.html",0);
      }
  /*
   elseif($action=="edit")
   {
       $validator = new FormValidator();
        $validator->addValidation('user_name','req','من فضلك ادخل  الاسم') ;
       $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;

       if(isset($submit)&&$validator->ValidateForm())
       {
          mysql_query("update user set group_id='$group',user_name='$user_name',
          password='".md5($password)."',email='$email',country='$country',
          city='$city',phone='$phone',mobile='$mobile' where id='$user_id'");
          $msg="تم التعديل";
          $sub= user();
       }
       else
       {
           $userquery=mysql_query("select * from user where id='$user_id'");
           while($userrow=mysql_fetch_array($userquery))
           {
             extract($userrow);
           }
           $groupquery=mysql_query("select * from groups");
          while($grouprow=mysql_fetch_array($groupquery))
          {
            extract($grouprow);
            $groups .="<option value=$group_id>$name</option>";
          }
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            } 
        $sub = Template_Array("$site_template/admin/user_add.html",0);
       }
   }
   */
   
  include_once("footer.php");
?>